@@ -27,10 +27,14 @@ use Config::IniFiles;
 #inherits Lemonldap::NG::Common::Conf::Backends::SOAP
 #inherits Lemonldap::NG::Common::Conf::Backends::LDAP
 
-our $VERSION = '2.0.14';
+our $VERSION = '2.0.15';
 our $msg     = '';
 our $iniObj;
 
+our $PlaceHolderRe = '%SERVERENV:(.*?)%';
+
+our $localconf;
+
 BEGIN {
     eval {
         require threads::shared;
@@ -70,7 +74,7 @@ sub new {
         unless ( $self->{type} ) {
 
             # Use local conf to get configStorage and localStorage
-            my $localconf =
+            $localconf =
               $self->getLocalConf( CONFSECTION, $self->{confFile}, 0 );
             if ( defined $localconf ) {
                 %$self = ( %$self, %$localconf );
@@ -115,7 +119,7 @@ sub new {
 # Serialize $conf and call store().
 # @param $conf Lemonldap::NG configuration hashRef
 # @param %args Parameters
-# @return Number of the saved configuration, 0 in case of error.
+# @return Number of the saved configuration, <=0 in case of error.
 sub saveConf {
     my ( $self, $conf, %args ) = @_;
 
@@ -147,7 +151,8 @@ sub saveConf {
         eval { Lemonldap::NG::Handler::Main->reload() };
     }
 
-    return ( $self->unlock() ? $tmp : UNKNOWN_ERROR );
+    $self->unlock();
+    return $tmp;
 }
 
 ## @method hashRef getConf(hashRef args)
@@ -228,9 +233,12 @@ sub getConf {
         $res = $r;
     }
 
-    # Create cipher object
+    # Create cipher object and replace variable placeholder
     unless ( $args->{raw} ) {
 
+        $res = { %$res, %$localconf };
+
+        $self->replacePlaceholders($res) if $self->{useServerEnv};
         eval {
             $res->{cipher} = Lemonldap::NG::Common::Crypto->new( $res->{key} );
         };
@@ -504,6 +512,46 @@ sub logError {
     return shift->_launch( 'logError', @_ );
 }
 
+sub _substPlaceHolders {
+    return $_[0] unless $_[0];
+    $_[0] =~ s/$PlaceHolderRe/$ENV{$1}/geo;
+    return $_[0];
+}
+
+## @method void replacePlaceholders(res: LLNG_Conf)
+#
+# Recursively replace %SERVERENV:VariableName% by $ENV{VariableName} value
+sub replacePlaceholders {
+    my ( $self, $conf ) = @_;
+    if ( ref $conf eq 'HASH' ) {
+        foreach my $key ( keys %$conf ) {
+            if ( $key =~ /$PlaceHolderRe/o ) {
+                my $val = $conf->{$key};
+                delete $conf->{$key};
+                my $nk = _substPlaceHolders($key);
+                $conf->{$nk} = $val;
+            }
+            next unless ( $conf->{$key} );
+            if ( ref $conf->{$key} ) {
+                $self->replacePlaceholders( $conf->{$key} );
+            }
+            elsif ( $conf->{$key} =~ /$PlaceHolderRe/o ) {
+                $conf->{$key} = _substPlaceHolders( $conf->{$key} );
+            }
+        }
+    }
+    elsif ( ref $conf eq 'ARRAY' ) {
+        for ( my $i = 0 ; $i < @$conf ; $i++ ) {
+            if ( ref $conf->[$i] ) {
+                $self->replacePlaceholders( $conf->[$i] );
+            }
+            elsif ( $conf->[$i] =~ /$PlaceHolderRe/o ) {
+                $conf->[$i] = _substPlaceHolders( $conf->[$i] );
+            }
+        }
+    }
+}
+
 1;
 __END__
 
