@@ -1,17 +1,17 @@
 package Lemonldap::NG::Common::Conf::AccessLib;
 
-use 5.10.0;
+use strict;
 use utf8;
 use Mouse;
 
 use Lemonldap::NG::Common::Conf;
 
 has '_confAcc'      => ( is => 'rw', isa => 'Lemonldap::NG::Common::Conf' );
-has 'configStorage' => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
-has 'currentConf' => ( is => 'rw', required => 1, default => sub { {} } );
-has 'protection'  => ( is => 'rw', isa      => 'Str', default => 'manager' );
+has 'configStorage' => ( is => 'rw', isa => 'HashRef',  default => sub { {} } );
+has 'currentConf'   => ( is => 'rw', required => 1,     default => sub { {} } );
+has 'protection'    => ( is => 'rw', isa      => 'Str', default => 'manager' );
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.0.11';
 
 ## @method Lemonldap::NG::Common::Conf confAcc()
 # Configuration access object
