@@ -6,24 +6,25 @@ use JSON;
 use Lemonldap::NG::Common::PSGI::Constants;
 use Lemonldap::NG::Common::PSGI::Request;
 
-our $VERSION = '2.0.15';
+our $VERSION = '2.17.0';
 
 our $_json = JSON->new->allow_nonref;
 
 # PROPERTIES
 
-has error        => ( is => 'rw', default => '' );
-has languages    => ( is => 'rw', isa     => 'Str', default => 'en' );
-has logLevel     => ( is => 'rw', isa     => 'Str', default => 'info' );
-has portal       => ( is => 'rw', isa     => 'Str' );
-has staticPrefix => ( is => 'rw', isa     => 'Str' );
-has instanceName => ( is => 'rw', isa     => 'Str', default => '' );
-has customCSS    => ( is => 'rw', isa     => 'Str', default => '' );
-has templateDir  => ( is => 'rw', isa     => 'Str|ArrayRef' );
-has links        => ( is => 'rw', isa     => 'ArrayRef' );
-has menuLinks    => ( is => 'rw', isa     => 'ArrayRef' );
-has logger       => ( is => 'rw' );
-has userLogger   => ( is => 'rw' );
+has error           => ( is => 'rw', default => '' );
+has languages       => ( is => 'rw', isa     => 'Str', default => 'en' );
+has logLevel        => ( is => 'rw', isa     => 'Str', default => 'info' );
+has portal          => ( is => 'rw', isa     => 'Str' );
+has staticPrefix    => ( is => 'rw', isa     => 'Str' );
+has instanceName    => ( is => 'rw', isa     => 'Str', default => '' );
+has customCSS       => ( is => 'rw', isa     => 'Str', default => '' );
+has customPortalUrl => ( is => 'rw', isa     => 'Str', default => '' );
+has templateDir     => ( is => 'rw', isa     => 'Str|ArrayRef' );
+has links           => ( is => 'rw', isa     => 'ArrayRef' );
+has menuLinks       => ( is => 'rw', isa     => 'ArrayRef' );
+has logger          => ( is => 'rw' );
+has userLogger      => ( is => 'rw' );
 
 # INITIALIZATION
 
@@ -237,10 +238,11 @@ sub sendRawHtml {
 sub abort {
     my ( $self, $err ) = @_;
     eval { $self->logger->error($err) };
-    return sub {
-        $self->sendError( Lemonldap::NG::Common::PSGI::Request->new( $_[0] ),
-            $err, 500 );
-    };
+    return $self->psgiAdapter(
+        sub {
+            $self->sendError( $_[0], $err, 500 );
+        }
+    );
 }
 
 sub _mustBeDefined {
@@ -347,14 +349,27 @@ sub run {
 
 sub _run {
     my $self = shift;
-    return sub {
-        $self->_logAndHandle(
-            Lemonldap::NG::Common::PSGI::Request->new( $_[0] ) );
-    };
+    return $self->psgiAdapter(
+        sub {
+            $self->handler( $_[0] );
+        }
+    );
 }
 
-sub _logAndHandle {
-    my ( $self, $req ) = @_;
+# This method turns a sub that takes a Lemonldap::NG::Common::PSGI::Request
+# obect and returns a PSGI response into a proper PSGI method.
+sub psgiAdapter {
+    my ( $self, $sub ) = @_;
+    return sub {
+        my $env = shift;
+        my $req = Lemonldap::NG::Common::PSGI::Request->new($env);
+        return $self->logAndRun( $req, $sub );
+    }
+}
+
+# This method sets up LemonLDAP::NG logging for the current request
+sub logAndRun {
+    my ( $self, $req, $sub ) = @_;
 
     # register the request object to the logging system
     if ( ref( $self->logger ) and $self->logger->can('setRequestObj') ) {
@@ -365,8 +380,12 @@ sub _logAndHandle {
         $self->userLogger->setRequestObj($req);
     }
 
-    # Call the handler
-    my $res = $self->handler($req);
+    $self->logger->info( "New request "
+          . ref($self) . " "
+          . $req->method . " "
+          . $req->request_uri );
+
+    my $res = $sub->($req);
 
     # Clear the logging system before the next request
     if ( ref( $self->logger ) and $self->logger->can('clearRequestObj') ) {
